#
# spec file for package gpu-screen-recorder
#
# Copyright (c) 2025 mantarimay
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with test
Name:           gpu-screen-recorder
Version:        20250224
Release:        1.1
Summary:        An extremely fast hardware-accelerated screen recorder
License:        GPL-3.0-only
URL:            https://git.dec05eba.com/gpu-screen-recorder/about
Source:         %{name}-%{version}.tar.zst
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vulkan-headers
BuildRequires:  zstd
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xrandr)

%description
This is a screen recorder that has minimal impact on system performance
by recording your monitor using the GPU only, similar to ShadowPlay on
windows. This is the fastest screen recording tool for Linux.

This screen recorder can be used for recording your desktop offline, for
live streaming and for nvidia ShadowPlay-like instant replay, where only
the last few minutes are saved.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%if 0%{?suse_version} < 1600
rm %{buildroot}/usr/lib/modprobe.d/gsr-nvidia.conf
%endif

%if %{with test}
%check
%meson_test
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_bindir}/gsr-kms-server
%{_userunitdir}/%{name}.service
%if 0%{?suse_version} > 1600
%{_modprobedir}/gsr-nvidia.conf
%endif

%changelog
* Tue Feb 25 2025 mantarimay@pm.me
- Update to version 20250224:
  * Higher jpeg quality, we can afford that
  * Fix merging audio with audio device and app audio where one
    audio device is a microphone with mono input
  * Dont show nvidia-smi output
  * Force nvenc codecs to work on opensuse
  * Make it possible to stop screenshot with sigint
  * Make image output lossy (use stb image writer), also
    significantly improves performance for jpeg
  * Make fps option (default to 60)
  * Mention that hdr only works in 'prefer color accuracy' mode
* Wed Feb 19 2025 mantarimay@pm.me
- Update to version 20250217:
  * Only show codec warning for image output
  * Support taking a screenshot (-o image.jpg/image.png)
  * Revert kde plasma 6.2 hdr workaround code
  * Info about hdr
  * Revert readme for hdr
  * Revert hdr color fix. It looked better for fullscreen hdr games
    before
  * Change hdr colors again
  * Make hdr better for limited range colors
  * Attempt to fix incorrect hdr colors on kde plasma 6.2
  * HDR: always set has_primaries and has_luminance, otherwise
    data will be missing from file
  * hdr works, for fullscreen applications?
  * Fix crash when trying to capture hdr and it fails
  * Increase replay max allowed duration to 3 hours
  * fix: proper cleanup for init_filter_graph
  * Pipewire: support 10-bit formats (where alpha is 2 bits, total
    32-bits)
* Sun Jan 26 2025 mantarimay@pm.me
- Update to version 20250125:
  * Fix microphone volume being low when merging audio devices
  * Dont normalize audio for mixed audio.
* Tue Jan 21 2025 mantarimay@pm.me
- Update to version 20250118:
  * Add a workaround for amd recording performance issue on wayland
    with a 10-bit monitor when recording a monitor instead of
    desktop portal. This is fixed in mesa version 25.0.0
  * Workaround possibly incorrect opengl setup and buggy nvidia
    driver (uses glx instead of egl).
  * Workaround teamspeak bug causing teamspeak to crash when
    recording application audio.
  * Fix possibility of monitor capture changing to another monitor
    on wayland when monitors are reconfigured.
* Fri Jan  3 2025 mantarimay@pm.me
- Update to version 20250102:
  * Better compatibility and performance on some older AMD GPUs
  * Better handle application audio nodes, fixing possible issue
    with application audio not working
* Sun Dec  8 2024 mantarimay@pm.me
- Update to version 20241208:
  * minor fixes and refactoring
  * Fix window creation on wayland
  * Add card path to --info, add card path and vendor to
  - -list-capture-options if known to speed up the command
  * Refactor windowing from egl to window_x11/window_wayland, yolo
  * Comment out unused egl priority for now because amd error is
    misleading
  * Fix virtual sink not destroyed if gsr is forcefully killed (use
    pipewire to create the virtual sink instead of pulseaudio)
  * Add error output when reaching max ports/stream nodes/links
  * Increase pipewire audio max nodes/ports limit
  * Remove incorrect references to -aa and -aai
* Tue Dec  3 2024 mantarimay@pm.me
- Update to version 20241130:
  * Fix application not starting on pulseaudio systems
  * Don't display monitor capture option when not available
* Thu Nov 21 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 20241121:
  * Allow recording from both audio devices and application audio
    at the same time
  * Workaround amd driver bug that causes garbage output on some
    gpus in some amd driver versions
  * Improve window content sizing behavior (no more horizontal
    scroll)
* Sat Nov 16 2024 mantarimay@pm.me
- Update to version 20241116:
  * Add support application audio recording
* Tue Nov  5 2024 mantarimay@pm.me
- Update to version 20241105:
  * Add option to change video resolution
  * Change quality parameters, file size was too large by default
  * Add option to change video resolution
  * Fix bitrate calculation being incorrect (it was too low)
* Tue Oct 22 2024 mantarimay@pm.me
- Update to version 20241022:
  * Fix capture not working if one of the audio inputs is a virtual
    audio device with forward slash in its name, for example if
    NoiseTorch is used
  * Enable AMD low latency mode
  * Better frame timing when hardware is too slow to record at the
    desired framerate
* Sat Oct 12 2024 mantarimay@pm.me
- Update to version 20241012:
  * Better frame timing for smoother video, especially when
    recording a game that runs at the same fps as the recording or
    lower.
  * Add constant bitrate option, for better live streaming
    experience and for lower file size at the cost of quality
- add vulkan-headers BuildRequires: to support vulkan video encode
* Mon Sep 23 2024 mantarimay@pm.me
- Update to version 20240921:
  * Fix recording not working on some amd systems
  * Improve screen recording performance on AMD when the system
    usage is very high
  * Fix recording not working on old nvidia gpus (that are stuck
    on nvidia driver version 470)
* Tue Sep 17 2024 mantarimay@pm.me
- Update to version 20240917:
  * Improve video capture sync, making the video smoother. The
    video is smoother on X11 than Wayland.
  * Improve video recording performance on AMD when the system
    usage is 100%%
- Remove pkgconfig(xi) BuildRequires: unneeded anymore on v4.1.8
* Tue Sep 10 2024 mantarimay@pm.me
- Update to version 20240906:
  * Portal: fix external texture
  * Allow prime run with desktop portal
  * Explicit glFlush/glFinish before and after render operations to
    fix tearing and stutter on amd
  * Fix systemd service file
* Sat Aug 31 2024 mantarimay@pm.me
- Update to version 20240831:
  * Disable vaapi info debug log
  * Faster startup (faster video codec query), fix some video codec
    callback logic
  * Add --version command
  * Improve quality again
* Tue Aug 20 2024 mantarimay@pm.me
- Update to version 20240820:
  * Also revert av1 quality
  * Revert quality parameters, they were overkill
  * Explain why portal needs access to process root file
  * x11 cursor deinit: check if display is valid
  * Small refactor in pipewire code, remove unused
    extra/install_preserve_video_memory.sh script
  * Don't install files using absolute paths
* Thu May 16 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
